darkhistory.history.histools — DarkHistory documentation

# darkhistory.history.histools

Functions and classes for processing lists of transfer functions.

Classes

`IonRSArray`(val_arr, x_arr, rs_arr[, in_eng, eng]) | Array of objects indexed by ionization and redshift.
`IonRSInterp`(ionrsarrays[, rs_nodes, log_interp]) | Interpolation function over list of IonRSArray objects.

#### Previous topic

darkhistory.history

#### Next topic

darkhistory.history.histools.IonRSArray

### This Page

Show Source